package net.t2code.t2codelib;


import java.util.List;

public interface T2CconfigItem {
    /**
     * Returns the path of the option for the config
     * @return Config path of the option
     */
    String getPath();

    /**
     * Returns the default value of the option and, after reading the config, the value from the config
     * @return Value of the option
     */
    Object getValue();

    /**
     * Here you determine whether the value should always be set (true) or only when the config is first created (false)
     */
    boolean getForceSet();

    /**
     * Set the description of the option here, the '# ' is automatically set in front of it
     */
    List<String> getComments();

    /**
     * This @void is used to reset the value of @getValue()
     */
    default void setValue(Object newValue){

    }


    /**
     *        Set in your Class
     *
     *       public enum VALUES implements T2CconfigItem {
     *         VALUE1("path", VALUE, true, "DESCRIPTION"),
     *         VALUE2("path", VALUE, true, "DESCRIPTION"),
     *
     *         ;
     *
     *         private final String path;
     *         private Object value;
     *         private final boolean forceSet;
     *         private final List<String> comments;
     *
     *         VALUES(String path, Object value,boolean forceSet, String... comments) {
     *             this.path = path;
     *             this.value = value;
     *             this.forceSet=forceSet;
     *             this.comments = new ArrayList<>(Arrays.asList(comments));
     *         }
     *
     *         @Override
     *         public String getPath() {
     *             return path;
     *         }
     *
     *         @Override
     *         public Object getValue() {
     *             return value;
     *         }
     *
     *         @Override
     *         public boolean getForceSet() {
     *             return forceSet;
     *         }
     *
     *         @Override
     *         public List<String> getComments() {
     *             return comments;
     *         }
     *
     *         @Override
     *         public void setValue(Object newValue) {
     *             value = newValue;
     *         }
     *     }
     *
     *     public static void set(){
     *         try {
     *             ConvertT2CBlibConfig.convert();
     *         } catch (IOException e) {
     *             throw new RuntimeException(e);
     *         }
     *         T2CBconfigWriter.createConfig(new File(getPlugin().getDataFolder(), "config.yml"), VALUES.values(), FILEHEADER);
     *     }
     */
}
